function [r,n,heatmap] = intersubject_score( yxt_subjs , yxt , imgsize , blur_width , make_figure , stimg , do_one_way )

if isempty(yxt_subjs) || isempty(yxt)
  r = NaN;
  n = NaN;
  heatmap = 0;
  return;
end

if ( nargin < 4 )
  blur_width = 0.15;
  skip_nss = 0;
  make_figure = 0;
  do_one_way = 0;
end

if ( nargin < 5 )
  skip_nss = 0;
  make_figure = 0;
  do_one_way = 0;
end

if ( nargin < 6 )
  make_figure = 0;
  do_one_way = 0;
end

heatmap = fix2heatmap( yxt_subjs(:,2) , yxt_subjs(:,1) , imgsize , [48 64] , blur_width );

if ( numel( unique(heatmap(:)) ) == 1 )
  r = NaN;
  n = NaN;
  heatmap = 0;
  return;
end

heatmap_ = fix2heatmap( yxt(:,2) , yxt(:,1) , imgsize , [48 64] , blur_width );

if ( numel( unique(heatmap_(:)) ) == 1 )
  r = NaN;
  n = NaN;
  heatmap = 0;
  return;
end

% roc + nss , both ways
r = rocScoreSaliencyVsFixations( heatmap , yxt(:,2) , yxt(:,1) , imgsize ) ;
n = nss( heatmap , yxt , imgsize );

if ( do_one_way )
  return;
end

r_ = rocScoreSaliencyVsFixations( heatmap_ , yxt_subjs(:,2) , yxt_subjs(:,1) , imgsize ) ;
n_ = nss( heatmap_ , yxt_subjs , imgsize );

if ( make_figure )
  figure;  
  subplot(2,2,1);
  imshow( stimg );
  title('Stimulus');

  subplot(2,2,2);
  f = [ yxt_subjs  ; yxt ];
  sN = [ ones( size(yxt_subjs,1) , 1 ); 2*ones( size(yxt,1) , 1) ];
  plotFixationsRaw( stimg , f(:,1), f(:,2) , sN , 500 );
  title('Scanpaths');

  subplot(2,2,3);  
  [omap,scale] = heatmap_overlay( stimg , heatmap );
  imshow(omap);
  hold on;
  plot( yxt(:,2) * scale , yxt(:,1) * scale , 'ko' , 'MarkerSize' , 12 , 'MarkerFaceColor' , 'y' );
  title(sprintf('NSS = %0.3g, ROC = %0.3g', n, r));

  subplot(2,2,4);  
  [omap,scale] = heatmap_overlay( stimg , heatmap_ );
  imshow(omap);
  hold on;
  plot( yxt_subjs(:,2) * scale , yxt_subjs(:,1) * scale , 'ko' , 'MarkerSize' , 12 , 'MarkerFaceColor' , 'y' );
  title(sprintf('NSS = %0.3g, ROC = %0.3g', n_, r_));
end


% average of both directions
r = (r + r_)/2;
n = (n + n_)/2;