function [map,k,recon] = pixsal( img , param )

recon = -1;
k = -1;
type = param.type;
T = param.T;
map = 0;

if ( strcmp(type,'cs') )

  summap = 0;
  for ssig = param.surroundSig
    ker = mygausskernel( ssig , 2 );
    map_ = mynorm( (img - myconv2(myconv2(img,ker),ker')).^2 , param );  
    if ( param.useNormWeights )
      wt_ = mypeakiness(map_);
    else
      wt_ = 1;
    end
    summap = summap + map_ * wt_;
  end  
  map = summap;

elseif ( strcmp(type,'identity') )

  img_minus_recon = img;

elseif ( T > 1 ) % fixed # of components

  if ( strcmp(type,'svd') )    
    [u s v] = svd( img );
    recon = u(:,1:T) * s(1:T,1:T) * v(:,1:T)';    
  elseif ( strcmp(type,'dct') )    
    d = dct2(img);
    d(:,T+1:end) = 0;
    d(T+1:end,:) = 0;
    recon = idct2(d);
  elseif ( strcmp(type,'fft') )
    % for fourier, must zero out UL, UR, BL, BR quadrants
    d = fft2(img);
    k = round(T/2);
    d(:,k+1:end-k) = 0;    
    d(k+1:end-k,:) = 0;
    recon = real(ifft2(d));
  end
  img_minus_recon = img - recon;    

elseif ( T > 0 ) % fixed reconstruction error

  if ( strcmp(type,'svd') )
    [u s v] = svd( img );
    for k = 1 : size(u,2)
      recon = u(:,1:k) * s(1:k,1:k) * v(:,1:k)';
      if (close_enough(img,recon,T)) break; end
    end
  elseif ( strcmp(type,'dct') )    
    dorig = dct2(img);
    for k = 1 : size(dorig,2)
      d = dorig;
      d(:,k+1:end) = 0;
      d(k+1:end,:) = 0;
      recon = idct2(d);
      if (close_enough(img,recon,T)) break; end
    end
  elseif ( strcmp(type,'fft') )    
    dorig = fft2(img);
    for k = 1 : size(dorig,2)
      d = dorig;
      d(:,k+1:end-k) = 0;
      d(k+1:end-k,:) = 0;
      recon = real(ifft2(d));
      if (close_enough(img,recon,T)) break; end
    end
  end
  img_minus_recon = img - recon;

elseif ( T == -1 )
  if ( strcmp(type,'svd') )  
    [u s v] = svd( img );
    img_minus_recon = u * eye(size(s)) * v';
    if ( nargout > 2 )
      recon = img - img_minus_recon;
    end
  elseif ( strcmp(type,'dct') )
    d = dct2(img);
    img_minus_recon = idct2(sign(d));
    if ( nargout > 2 )      
      mu = mean(abs(d(:)));
      recon = img - mu * img_minus_recon;
    end
  elseif ( strcmp(type,'fft') )    
    d = fft2(img);
    phaseinfo = d ./ (abs(d)+1e-6);
    img_minus_recon = real( ifft2( phaseinfo ) );    
    if ( nargout > 2 )
      mu = mean(abs(d(:)));
      recon = img - mu * img_minus_recon;
    end
  end
else % (-1 < T < 0 )

  ptile = -T * 100;
  
  if ( strcmp(type,'svd') )  % already ordered
    [u s v] = svd( img );
    ds = diag(s);    
    thresh = prctile( ds , ptile );
    smod = s; smod( s>=thresh) = 0;
    img_minus_recon = u * smod * v';
    if ( nargout > 2 )
      recon = img - img_minus_recon;
    end

  elseif ( strcmp(type,'dct') )
    d = dct2(img);
    ad = abs(d(:));
    thresh = prctile( ad , ptile );

    % preserve only phase in greatest components
    ix = ad >= thresh;
    if ( param.phasePreserve )
      d(ix) = thresh * sign(d(ix));
    else
      d(ix) = 0;
    end
    img_minus_recon = idct2(d);
    
    if ( nargout > 2 )
      mu = mean(ad);
      recon = img - mu * img_minus_recon;
    end
  elseif ( strcmp(type,'fft') )    
    d = fft2(img);
    ad = abs(d(:));
    thresh = prctile( ad , ptile );

    % preserve only phase in greatest components
    ix = ad>=thresh;
    if ( param.phasePreserve )
      d(ix) = thresh * d(ix) ./ (ad(ix)+1e-6);
    else
      d(ix) = 0;
    end

    img_minus_recon = ifft2(d);
    
    if ( nargout > 2 )
      mu = mean(ad);
      recon = img - mu * img_minus_recon;
    end
  end
end

if ( map == 0 )
  map = img_minus_recon .^ 2;
end

map = mynorm(map,param);