function computeROC(algoParams, setParams)
%% params
algoList = algoParams.algoList;
algoNum = algoParams.algoNum;

setImgNum = setParams.setImgNum;

shrinkRatio = 4;	% this parameter shrinks the fixation map for faster computation (e.g. compute the salmaps of 256341 instead of 511*681)
sigmaList = 0.01:0.005:0.13;




%%
load origfixdata.mat;		% the original file downloaded from Neil Bruce's website.  Please cite his works!
load salData/salMap.mat;	% saliency maps computed by computeSalMaps.m
load salData/sizeMat.mat;	% sizes of images computed by computeSalMaps.m

sigmaLen = length(sigmaList);
rocMat = zeros(sigmaLen, algoNum);

mapSize = ceil(sizeMat(:,1)./shrinkRatio)';
setTotalFix = zeros(mapSize);		% total fixation map to cancel center-bias

for curImgNum = 1:setImgNum
	curFix = white{curImgNum};
	[fixH, fixW] = find(curFix);
	fixH = ceil(fixH./shrinkRatio);
	fixW = ceil(fixW./shrinkRatio);
	fixInd = sub2ind(mapSize, fixH, fixW);
	setTotalFix(fixInd) = setTotalFix(fixInd) + 1;
end


for curAlgo = 1:algoNum
	for curSigma = 1:sigmaLen
		tempROC = zeros(setImgNum, 1);
		fprintf('Current Algorithm: %s, current sigma: %0.3f.   ', algoList{curAlgo}, sigmaList(curSigma));
		parfor curImgNum = 1:setImgNum
			imgSize = sizeMat(:, curImgNum);
			curSMap = salMap{curImgNum, curAlgo};
			tempROC(curImgNum) = rocScoreXD(curSMap, sigmaList(curSigma), white{curImgNum}, setTotalFix, shrinkRatio);
		end
		rocMat(curSigma, curAlgo) = mean(tempROC);
		fprintf('Mean ROC = %0.4f\n', mean(tempROC));
	end
end


save('salData/ROC.mat', 'rocMat', 'sigmaList');		% save plot data for makeFig_ROC.m

end