function makeFig_ROC(algoParams, setParams)

dataSet = setParams.datasetName;
figuresDir = 'figures';
load salData/ROC.mat;

nImg = setParams.setImgNum;
%%
lineStyleBank = algoParams.lineStyleBank;
myColor = algoParams.colors;

algoList = algoParams.algoList;
algoNum = algoParams.algoNum;

%% Figure style
figure();
hold on;
myRange = [0.01 0.13 0.55 0.75];
dx = .0025;


%% Drawing

sigma_star = zeros(2, algoNum);
for curAlgo = 1:algoNum
	lh = plot(sigmaList, (rocMat(:, curAlgo)), lineStyleBank{curAlgo}, 'linewidth', 2);
	set(lh,'Color', myColor{curAlgo});
	
	[maxVal,maxIndex] = max(rocMat(:, curAlgo));
	sigma_star(1, curAlgo) = sigmaList(maxIndex);
	sigma_star(2, curAlgo) = maxVal;
end

lh = legend( algoList );		% name your algorithm here
set(lh,'FontSize', 10);

for curAlgo = 1:algoNum
	lh = scatter(sigma_star(1, curAlgo), sigma_star(2, curAlgo));
	set(lh,'MarkerFaceColor', myColor{curAlgo});
	set(lh,'MarkerEdgeColor', myColor{curAlgo});
end

grid on;
axis(myRange);

xlabel( sprintf('Blur Width\n(STD of Gaussian kernel in image widths)') , 'FontSize', 11);
ylabel( sprintf('ROC Score\n(averaged across %d images)', nImg) , 'FontSize', 11);
title(sprintf('ROC Score Dependence on Blur'), 'FontSize', 12);

paperPosition=[0 0 7.2 6];
set(gcf,'PaperUnits','inches','PaperPosition',paperPosition)
print(gcf,'-depsc2', sprintf('%s/X-%s_opt.eps', figuresDir , dataSet));

end

