function makeFig_computetime(algoParams, setParams)

figuresDir = 'figures';
load salData/timeMat.mat;

%% Specs
algoList = algoParams.algoList;
algoNum = algoParams.algoNum;
myColor = algoParams.colors;

nImg = setParams.setImgNum;

%% Figure style
figure();
hold on;
ylim([0, 1.45]);

dx = 0.3;
dy = 0.03;
dtext = 0.05;
barWidth = 0.15;
barBreakLower = 0.9;
barBreakLen = 0.4;
centerPos = 1;

%% Drawing

meanTime = mean(timeMat(1:nImg, :), 1);
maxTime = max(meanTime);
for curAlgo = 1:algoNum
	curMeanTime = meanTime(curAlgo);
	if curMeanTime>barBreakLower
		curBarTime = curMeanTime/maxTime * barBreakLen + barBreakLower;
	else
		curBarTime = curMeanTime;
	end
	
	bh = bar(centerPos - (5-curAlgo)*dx , curBarTime , barWidth);
	set(bh,'FaceColor', myColor{curAlgo} );
	text( centerPos - (5-curAlgo)*dx - dtext , curBarTime + dy , sprintf('%0.3f' , curMeanTime) , 'fontsize' , 8 , 'fontweight', 'bold' );
	
end


set(gca,'XTick',centerPos);
set(gca,'XTickLabel',{''})

lh = legend( algoList );
ylabel( 'Average Compute Time (s)' );
title( 'Computational Complexity Comparison' );

paperPosition=[0 0 7.2 6];
set(gcf,'PaperUnits','inches','PaperPosition',paperPosition)
print(gcf,'-depsc2', sprintf('%s/X-saliency_compute_time.eps', figuresDir ));


end